@@ -47,6 +47,8 @@ class HBaseConnection(object):
     exceptionType, exception, tracebackInfo = sys.exc_info()
     raise exception
 
+  # TODO(hammer): classify these methods like the HBase shell
+
   #
   # Metadata
   #
@@ -56,6 +58,16 @@ class HBaseConnection(object):
     """Grab table information."""
     return self.requestor.request("listTables", {})
 
+  @retry_wrapper
+  def describe_table(self, table):
+    """Grab table information."""
+    return self.requestor.request("describeTable", {"table": table})
+
+  @retry_wrapper
+  def describe_family(self, table, family):
+    """Grab family information."""
+    return self.requestor.request("describeFamily", {"table": table, "family": family})
+
   @retry_wrapper
   def is_table_enabled(self, table):
     """Determine if a table is enabled."""
@@ -84,11 +96,11 @@ class HBaseConnection(object):
   # Get
   #
 
+  # TODO(hammer): Figure out how to get binary keys
+  # TODO(hammer): Do this parsing logic in pyhbase-cli?
   @retry_wrapper
   def get(self, table, row, *columns):
     get = {"row": row}
-
-    # from my upcoming book, "how to abuse python for recovering perl addicts"
     columns = [len(column) > 1 and {"family": column[0], "qualifier": column[1]} or {"family": column[0]}
                for column in map(lambda s: s.split(":"), columns)]
     if columns: get["columns"] = columns
@@ -99,6 +111,17 @@ class HBaseConnection(object):
   # Put
   #
 
+  # TODO(hammer): Figure out how to incorporate timestamps
+  # TODO(hammer): Do this parsing logic in pyhbase-cli?
+  @retry_wrapper
+  def put(self, table, row, *column_values):
+    put = {"row": row}
+    column_values = [{"family": column.split(":")[0], "qualifier": column.split(":")[1], "value": value}
+                     for column, value in zip(column_values[::2], column_values[1::2])]
+    put["columnValues"] = column_values
+    params = {"table": table, "put": put}
+    return self.requestor.request("put", params)
+
   #
   # Delete
   #
@@ -107,3 +130,12 @@ class HBaseConnection(object):
   # Scan
   #
 
+  # TODO(hammer): Figure out cleaner, more functional command-line
+  @retry_wrapper
+  def scan(self, table, number_of_rows):
+    params = {"table": table, "scan": {}}
+    scanner_id = self.requestor.request("scannerOpen", params)
+    results = self.requestor.request("scannerGetRows", {"scannerId": scanner_id, "numberOfRows": int(number_of_rows)})
+    self.requestor.request("scannerClose", {"scannerId": scanner_id})
+    return results
+
